@@ -3,6 +3,7 @@ import optparse
 
 import sentry_sdk
 from sentry_sdk.integrations.logging import LoggingIntegration
+
 try:
     import pyramid  # noqa
 except ImportError:
@@ -15,24 +16,27 @@ else:
 def init_sdk(cwconfig):
     """Initialize `sentry_sdk` from cubicweb configuration."""
     try:
-        dsn = cwconfig['sentry-dsn']
+        dsn = cwconfig["sentry-dsn"]
     except (optparse.OptionError, KeyError):
         return
     if not dsn:
         return
     release = cwconfig.cube_version(cwconfig.cubes()[0])
-    log_level = cwconfig['sentry-log-level']
+    log_level = cwconfig["sentry-log-level"]
     integrations = []
     if HAS_PYRAMID:
         integrations.append(PyramidIntegration())
     if log_level is not None:
-        integrations.append(LoggingIntegration(
-            level=logging.DEBUG,  # Capture debug and above as breadcrumbs
-            event_level=log_level.upper(),
-        ))
+        integrations.append(
+            LoggingIntegration(
+                level=logging.DEBUG,  # Capture debug and above as breadcrumbs
+                event_level=log_level.upper(),
+            )
+        )
     sentry_sdk.init(
         dsn=dsn,
         release=release,
         integrations=integrations,
+        environment=cwconfig["sentry-environment"],
     )
     return sentry_sdk
