@@ -4,7 +4,7 @@
 modname = "sentry"
 distname = "cubicweb-sentry"
 
-numversion = (0, 8, 0)
+numversion = (0, 8, 1)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -20,6 +20,5 @@ classifiers = [
     "Programming Language :: JavaScript",
 ]
 
-__depends__ = {"cubicweb": ">= 3.24.0, < 3.38.0", "sentry-sdk": None}
-
+__depends__ = {"cubicweb": ">= 3.24.0, < 3.39.0", "sentry-sdk": "<1.9.8"}
 __recommends__ = {}
